/*
 * Copyright 2023-2024 Hartmut Seichter
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */
#ifndef PARADISO_BITMAP_IO_HPP
#define PARADISO_BITMAP_IO_HPP

#include <paradiso/bitmap.hpp>

#include <string_view>
#include <memory>

namespace paradiso {

struct BitmapIO {

    static BitmapIO& get();

    Bitmap load(std::string_view filename, bool ignore_cache = false) const;

    void set_path(std::string_view path);

    std::string path() const;

  private:

    struct Impl;
    std::unique_ptr<Impl> impl_;

    BitmapIO();
    ~BitmapIO() = default;
    BitmapIO(const BitmapIO&) = delete;
    BitmapIO(BitmapIO&&) = delete;
};

} // namespace paradiso

#endif
